@@ -2,11 +2,10 @@
 Reads reports from a CSV and submits them to TruSTAR.
 """
 
-from trustar import TruStar, Report
+from trustar import log, Report, TruStar
 import csv
-import logging
 
-logger = logging.getLogger(__name__)
+logger = log.get_logger(__name__)
 
 # mapping of CSV column names to report fields
 MAPPING = {
